@@ -1,5 +1,5 @@
 package Email::MIME::RFC2047::Address;
-$Email::MIME::RFC2047::Address::VERSION = '0.93';
+$Email::MIME::RFC2047::Address::VERSION = '0.94';
 use strict;
 use warnings;
 
@@ -25,14 +25,14 @@ sub parse {
 
     my $address;
 
-    if($$string_ref =~ /\G\s*($addr_spec_re)\s*/cg) {
+    if ($$string_ref =~ /\G\s*($addr_spec_re)\s*/cg) {
         $address = Email::MIME::RFC2047::Mailbox->new($1);
     }
     else {
         $decoder ||= Email::MIME::RFC2047::Decoder->new();
         my $name = $decoder->decode_phrase($string_ref);
 
-        if($$string_ref =~ /\G<\s*($addr_spec_re)\s*>\s*/cg) {
+        if ($$string_ref =~ /\G<\s*($addr_spec_re)\s*>\s*/cg) {
             my $addr_spec = $1;
 
             $address = Email::MIME::RFC2047::Mailbox->new(
@@ -41,13 +41,13 @@ sub parse {
 
             $address->name($name) if $name ne '';
         }
-        elsif($$string_ref =~ /\G:/cg) {
+        elsif ($$string_ref =~ /\G:/cg) {
             return $class->_parse_error($string_ref, 'group name')
                 if $name eq '';
 
             my $mailbox_list;
 
-            if($$string_ref =~ /\G\s*;\s*/cg) {
+            if ($$string_ref =~ /\G\s*;\s*/cg) {
                 $mailbox_list = Email::MIME::RFC2047::MailboxList->new();
             }
             else {
@@ -69,7 +69,7 @@ sub parse {
         }
     }
 
-    if(!ref($string) && pos($string) < length($string)) {
+    if (!ref($string) && pos($string) < length($string)) {
         return $class->_parse_error($string_ref);
     }
 
@@ -90,18 +90,18 @@ Email::MIME::RFC2047::Address - Handling of MIME encoded addresses
 
 =head1 VERSION
 
-version 0.93
+version 0.94
 
 =head1 SYNOPSIS
 
- use Email::MIME::RFC2047::Address;
+    use Email::MIME::RFC2047::Address;
 
- my $address = Email::MIME::RFC2047::Address->parse($string);
+    my $address = Email::MIME::RFC2047::Address->parse($string);
 
- if($address->isa('Email::MIME::RFC2047::Mailbox')) {
-    print $address->name(), "\n";
-    print $address->address(), "\n";
- }
+    if ($address->isa('Email::MIME::RFC2047::Mailbox')) {
+       print $address->name(), "\n";
+       print $address->address(), "\n";
+    }
 
 =head1 DESCRIPTION
 
@@ -112,10 +112,10 @@ L<Email::MIME::RFC2047::Group>.
 
 =head2 parse
 
- my $address = Email::MIME::RFC2047::Address->parse($string, [$decoder])
+    my $address = Email::MIME::RFC2047::Address->parse($string, [$decoder])
 
-Parses a RFC 2822 'address'. Returns either a L<Email::MIME::RFC2047::Mailbox>
-or a L<Email::MIME::RFC2047::Group> object.
+Parses a RFC 2822 C<address>. Returns either a
+L<Email::MIME::RFC2047::Mailbox> or a L<Email::MIME::RFC2047::Group> object.
 
 =head1 AUTHOR
 
@@ -123,7 +123,7 @@ Nick Wellnhofer <wellnhofer@aevum.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Nick Wellnhofer.
+This software is copyright (c) 2016 by Nick Wellnhofer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
