@@ -1,5 +1,5 @@
 package Email::MIME::RFC2047::Encoder;
-$Email::MIME::RFC2047::Encoder::VERSION = '0.93';
+$Email::MIME::RFC2047::Encoder::VERSION = '0.94';
 use strict;
 use warnings;
 
@@ -16,7 +16,7 @@ sub new {
 
     my ($encoding, $method) = ($options->{encoding}, $options->{method});
 
-    if(!defined($encoding)) {
+    if (!defined($encoding)) {
         $encoding = 'utf-8';
         $method = 'Q' if !defined($method);
     }
@@ -70,26 +70,26 @@ sub _encode {
 
         my $word_type;
 
-        if($word =~ /[\x80-\x{10ffff}]|(^=\?.*\?=\z)/s) {
+        if ($word =~ /[\x80-\x{10ffff}]|(^=\?.*\?=\z)/s) {
             # also encode any word that starts with '=?' and ends with '?='
             $word_type = 'mime';
         }
-        elsif($mode eq 'phrase') {
+        elsif ($mode eq 'phrase') {
             $word_type = 'quoted';
         }
         else {
             $word_type = 'text';
         }
-        
+
         $self->_finish_buffer(\$result, $buffer_type, \$buffer)
             if $buffer ne '' && $buffer_type ne $word_type;
         $buffer_type = $word_type;
 
-        if($word_type eq 'text') {
+        if ($word_type eq 'text') {
             $result .= ' ' if $result ne '';
             $result .= $word;
         }
-        elsif($word_type eq 'quoted') {
+        elsif ($word_type eq 'quoted') {
             $buffer .= ' ' if $buffer ne '';
             $buffer .= $word;
         }
@@ -103,32 +103,32 @@ sub _encode {
 
             for my $char (@chars) {
                 my $chunk;
-                
-                if($self->{method} eq 'B') {
+
+                if ($self->{method} eq 'B') {
                     $chunk = $encoder->encode($char);
                 }
-                elsif($char =~ /[()<>@,;:\\".\[\]=?_]/) {
+                elsif ($char =~ /[()<>@,;:\\".\[\]=?_]/) {
                     # special character
                     $chunk = sprintf('=%02x', ord($char));
                 }
-                elsif($char =~ /[\x80-\x{10ffff}]/) {
+                elsif ($char =~ /[\x80-\x{10ffff}]/) {
                     # non-ASCII character
 
                     my $enc_char = $encoder->encode($char);
                     $chunk = '';
-                    
+
                     for my $byte (unpack('C*', $enc_char)) {
                         $chunk .= sprintf('=%02x', $byte);
                     }
                 }
-                elsif($char eq ' ') {
+                elsif ($char eq ' ') {
                     $chunk = '_';
                 }
                 else {
                     $chunk = $char;
                 }
 
-                if(length($buffer) + length($chunk) <= $max_len) {
+                if (length($buffer) + length($chunk) <= $max_len) {
                     $buffer .= $chunk;
                 }
                 else {
@@ -150,21 +150,21 @@ sub _finish_buffer {
 
     $$result .= ' ' if $$result ne '';
 
-    if($buffer_type eq 'quoted') {
-        if($$buffer =~ /[$rfc_specials]/) {
+    if ($buffer_type eq 'quoted') {
+        if ($$buffer =~ /[$rfc_specials]/) {
             # use quoted string if buffer contains special chars
             $$buffer =~ s/[\\"]/\\$&/g;
-            
+
             $$result .= qq("$$buffer");
         }
         else {
             $$result .= $$buffer;
         }
     }
-    elsif($buffer_type eq 'mime') {
+    elsif ($buffer_type eq 'mime') {
         $$result .= "=?$self->{encoding}?$self->{method}?";
 
-        if($self->{method} eq 'B') {
+        if ($self->{method} eq 'B') {
             $$result .= MIME::Base64::encode_base64($$buffer, '');
         }
         else {
@@ -193,19 +193,19 @@ Email::MIME::RFC2047::Encoder - Encoding of non-ASCII MIME headers
 
 =head1 VERSION
 
-version 0.93
+version 0.94
 
 =head1 SYNOPSIS
 
- use Email::MIME::RFC2047::Encoder;
- 
- my $encoder = Email::MIME::RFC2047::Encoder->new(
-     encoding => 'utf-8',
-     method   => 'Q',
- );
- 
- my $encoded_text   = $encoder->encode_text($string);
- my $encoded_phrase = $encoder->encode_phrase($string);
+    use Email::MIME::RFC2047::Encoder;
+
+    my $encoder = Email::MIME::RFC2047::Encoder->new(
+        encoding => 'utf-8',
+        method   => 'Q',
+    );
+
+    my $encoded_text   = $encoder->encode_text($string);
+    my $encoded_phrase = $encoder->encode_phrase($string);
 
 =head1 DESCRIPTION
 
@@ -216,51 +216,52 @@ RFC 2047.
 
 =head2 new
 
- my $encoder = Email::MIME::RFC2047::Encoder->new(
-     encoding => $encoding,
-     method   => $method,
- );
+    my $encoder = Email::MIME::RFC2047::Encoder->new(
+        encoding => $encoding,
+        method   => $method,
+    );
 
 Creates a new encoder object.
 
-I<encoding> specifies the encoding ("character set" in the RFC) to use. This is
-passed to the L<Encode> module. See L<Encode::Supported> for supported
-encodings.
+I<encoding> specifies the encoding ("character set" in the RFC) to use. This
+is passed to L<Encode>. See L<Encode::Supported> for supported encodings.
 
-I<method> specifies the encoding method ("encoding" in the RFC). Must be either
-'B' or 'Q'.
+I<method> specifies the encoding method ("encoding" in the RFC). Must be
+either C<'B'> or C<'Q'>.
 
-If both I<encoding> and I<method> are omitted, encoding defaults to 'utf-8'
-and method to 'Q'. If only I<encoding> is omitted it defaults to 'utf-8'.
-If only I<method> is omitted it defaults to 'B'.
+If both I<encoding> and I<method> are omitted, encoding defaults to
+C<'utf-8'> and method to C<'Q'>. If only I<encoding> is omitted, it defaults
+to C<'utf-8'>. If only I<method> is omitted, it defaults to C<'B'>.
 
 =head1 METHODS
 
 =head2 encode_text
 
- my $encoded_text = $encoder->encode_text($string);
+    my $encoded_text = $encoder->encode_text($string);
 
-Encodes a string that may replace a sequence of 'text' tokens (as defined by
-RFC 822) in any Subject or Comments header field, any extension message header
-field, or any MIME body part field for which the field body is defined as
-'*text'. $string is expected to be an unencoded perl string.
+Encodes a string for use in any I<Subject> or I<Comments> header field, any
+extension message header field, or any MIME body part field for which the
+field body is defined as C<unstructured> (RFC 2822) or C<*text> (RFC 822).
+C<$string> is expected to be an unencoded perl string.
 
 This method tries to use the MIME encoding for as few characters of the
-input string as possible. So the result may consist of a mix of
-'encoded-words' and '*text'.
+input string as possible. So the result may consist of a mix of encoded and
+unencoded words.
 
-The source string is trimmed and any whitespace is collapsed. The words in the
-result are separated by single space characters without folding of long lines.
+The source string is trimmed and any whitespace is collapsed. The words in
+the result are separated by single space characters without folding of long
+lines.
 
 =head2 encode_phrase
 
- my $encoded_phrase = $encoder->encode_phrase($string);
+    my $encoded_phrase = $encoder->encode_phrase($string);
 
-Encodes a string that may replace a 'phrase' token (as defined by RFC 822),
-for example, one that precedes an address in a From, To, or Cc header.
+Encodes a string that may replace a C<phrase> token (as defined by RFC 2822),
+for example, one that precedes an address in a I<From>, I<To>, or I<Cc>
+header.
 
 This method works like I<encode_text> but additionally converts remaining
-text that contains special characters to 'quoted-strings'.
+text that contains special characters to C<quoted-string>s.
 
 =head1 AUTHOR
 
@@ -268,7 +269,7 @@ Nick Wellnhofer <wellnhofer@aevum.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Nick Wellnhofer.
+This software is copyright (c) 2016 by Nick Wellnhofer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
