@@ -1,5 +1,5 @@
 package Email::MIME::RFC2047::Group;
-$Email::MIME::RFC2047::Group::VERSION = '0.93';
+$Email::MIME::RFC2047::Group::VERSION = '0.94';
 use strict;
 use warnings;
 
@@ -15,7 +15,7 @@ sub new {
 
     my $self;
 
-    if(@_ >= 2) {
+    if (@_ >= 2) {
         $self = { @_ };
     }
     else {
@@ -40,8 +40,8 @@ sub _parse {
         or return $class->_parse_error($string_ref, 'group');
 
     my $mailbox_list;
-    
-    if($$string_ref =~ /\G\s*;\s*/cg) {
+
+    if ($$string_ref =~ /\G\s*;\s*/cg) {
         $mailbox_list = Email::MIME::RFC2047::MailboxList->new();
     }
     else {
@@ -58,7 +58,7 @@ sub _parse {
         mailbox_list => $mailbox_list,
     );
 
-    if(!ref($string) && pos($string) < length($string)) {
+    if (!ref($string) && pos($string) < length($string)) {
         return $class->_parse_error($string_ref);
     }
 
@@ -67,7 +67,7 @@ sub _parse {
 
 sub name {
     my $self = shift;
-    
+
     my $old_name = $self->{name};
     $self->{name} = $_[0] if @_;
 
@@ -76,7 +76,7 @@ sub name {
 
 sub mailbox_list {
     my $self = shift;
-    
+
     my $old_mailbox_list = $self->{mailbox_list};
     $self->{mailbox_list} = $_[0] if @_;
 
@@ -114,57 +114,57 @@ Email::MIME::RFC2047::Group - Handling of MIME encoded mailbox groups
 
 =head1 VERSION
 
-version 0.93
+version 0.94
 
 =head1 SYNOPSIS
 
- use Email::MIME::RFC2047::Group;
+    use Email::MIME::RFC2047::Group;
 
- my $group = Email::MIME::RFC2047::Group->new(
-    name => $name,
-    mailbox_list => $mailbox_list,
- );
- $email->header_set('To', $group->format());
+    my $group = Email::MIME::RFC2047::Group->new(
+       name => $name,
+       mailbox_list => $mailbox_list,
+    );
+    $email->header_set('To', $group->format());
 
 =head1 DESCRIPTION
 
-This module handles RFC 2822 'groups'.
+This module handles RFC 2822 C<group>s.
 
 =head1 CONSTRUCTOR
 
 =head2 new
 
- my $group = Email::MIME::RFC2047::Group->new(
-    name => $name,
-    mailbox_list => $mailbox_list,
- );
+    my $group = Email::MIME::RFC2047::Group->new(
+       name => $name,
+       mailbox_list => $mailbox_list,
+    );
 
 Creates a new Email::MIME::RFC2047::Group object, optionally with a
-display name $name and an mailbox list $mailbox_list.
+display name C<$name> and an mailbox list C<$mailbox_list>.
 
 =head1 METHODS
 
 =head2 name
 
- my $name = $group->name();
- $group->name($new_name);
+    my $name = $group->name();
+    $group->name($new_name);
 
 Gets or sets the display name of the group.
 
 =head2 mailbox_list
 
- my $mailbox_list = $group->mailbox_list();
- $group->mailbox_list($new_mailbox_list);
+    my $mailbox_list = $group->mailbox_list();
+    $group->mailbox_list($new_mailbox_list);
 
 Gets or sets the mailbox list of the group.
 
 =head2 format
 
- my $string = $group->format([$encoder]);
+    my $string = $group->format([$encoder]);
 
 Returns the formatted string for use in a message header.
 
-$encoder is an optional L<Email::MIME::RFC2047::Encoder> object used for
+C<$encoder> is an optional L<Email::MIME::RFC2047::Encoder> object used for
 encoding display names with non-ASCII characters.
 
 =head1 AUTHOR
@@ -173,7 +173,7 @@ Nick Wellnhofer <wellnhofer@aevum.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Nick Wellnhofer.
+This software is copyright (c) 2016 by Nick Wellnhofer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
