@@ -1,5 +1,5 @@
 package Email::MIME::RFC2047::Mailbox;
-$Email::MIME::RFC2047::Mailbox::VERSION = '0.93';
+$Email::MIME::RFC2047::Mailbox::VERSION = '0.94';
 use strict;
 use warnings;
 
@@ -22,10 +22,10 @@ sub new {
 
     my $self;
 
-    if(@_ >= 2) {
+    if (@_ >= 2) {
         $self = { @_ };
     }
-    elsif(ref($_[0])) {
+    elsif (ref($_[0])) {
         $self = $_[0];
     }
     else {
@@ -41,7 +41,7 @@ sub parse {
 
     my $mailbox;
 
-    if($$string_ref =~ /\G\s*($addr_spec_re)\s*/cg) {
+    if ($$string_ref =~ /\G\s*($addr_spec_re)\s*/cg) {
         $mailbox = $class->new($1);
     }
     else {
@@ -55,7 +55,7 @@ sub parse {
         $mailbox = $class->new(name => $name, address => $addr_spec);
     }
 
-    if(!ref($string) && pos($string) < length($string)) {
+    if (!ref($string) && pos($string) < length($string)) {
         return $class->_parse_error($string_ref);
     }
 
@@ -64,7 +64,7 @@ sub parse {
 
 sub name {
     my $self = shift;
-    
+
     my $old_name = $self->{name};
     $self->{name} = $_[0] if @_;
 
@@ -73,7 +73,7 @@ sub name {
 
 sub address {
     my $self = shift;
-    
+
     my $old_address = $self->{address};
     $self->{address} = $_[0] if @_;
 
@@ -90,7 +90,7 @@ sub format {
 
     my $result;
 
-    if(!defined($name) || $name eq '') {
+    if (!defined($name) || $name eq '') {
         $result = $address;
     }
     else {
@@ -117,69 +117,69 @@ Email::MIME::RFC2047::Mailbox - Handling of MIME encoded mailboxes
 
 =head1 VERSION
 
-version 0.93
+version 0.94
 
 =head1 SYNOPSIS
 
- use Email::MIME::RFC2047::Mailbox;
+    use Email::MIME::RFC2047::Mailbox;
 
- my $mailbox = Email::MIME::RFC2047::Mailbox->parse($string);
- print $mailbox->name(), "\n";
- print $mailbox->address(), "\n";
+    my $mailbox = Email::MIME::RFC2047::Mailbox->parse($string);
+    print $mailbox->name(), "\n";
+    print $mailbox->address(), "\n";
 
- my $mailbox = Email::MIME::RFC2047::Mailbox->new(
-    name => $name,
-    address => $address,
- );
- $email->header_set('To', $mailbox->format());
+    my $mailbox = Email::MIME::RFC2047::Mailbox->new(
+       name => $name,
+       address => $address,
+    );
+    $email->header_set('To', $mailbox->format());
 
 =head1 DESCRIPTION
 
-This module handles RFC 2822 'mailboxes'.
+This module handles RFC 2822 C<mailbox>es.
 
 =head1 CLASS METHODS
 
 =head2 parse
 
- my $mailbox = Email::MIME::RFC2047::Mailbox->parse($string, [$decoder])
+    my $mailbox = Email::MIME::RFC2047::Mailbox->parse($string, [$decoder])
 
-Parse a RFC 2822 'mailbox'. Returns a Email::MIME::RFC2047::Mailbox object.
+Parse a RFC 2822 C<mailbox>. Returns a Email::MIME::RFC2047::Mailbox object.
 
 =head1 CONSTRUCTOR
 
 =head2 new
 
- my $mailbox = Email::MIME::RFC2047::Mailbox->new(
-    name => $name,
-    address => $address,
- );
+    my $mailbox = Email::MIME::RFC2047::Mailbox->new(
+       name => $name,
+       address => $address,
+    );
 
-Creates a new Email::MIME::RFC2047::Mailbox object, optionally  with a
-display name $name and an email address $address.
+Creates a new Email::MIME::RFC2047::Mailbox object, optionally with a
+display name C<$name> and an email address C<$address>.
 
 =head1 METHODS
 
 =head2 name
 
- my $name = $mailbox->name();
- $mailbox->name($new_name);
+    my $name = $mailbox->name();
+    $mailbox->name($new_name);
 
 Gets or sets the display name of the mailbox.
 
 =head2 address
 
- my $address = $mailbox->address();
- $mailbox->address($new_address);
+    my $address = $mailbox->address();
+    $mailbox->address($new_address);
 
 Gets or sets the email address of the mailbox.
 
 =head2 format
 
- my $string = $mailbox->format([$encoder]);
+    my $string = $mailbox->format([$encoder]);
 
 Returns the formatted mailbox string for use in a message header.
 
-$encoder is an optional L<Email::MIME::RFC2047::Encoder> object used for
+C<$encoder> is an optional L<Email::MIME::RFC2047::Encoder> object used for
 encoding display names with non-ASCII characters.
 
 =head1 AUTHOR
@@ -188,7 +188,7 @@ Nick Wellnhofer <wellnhofer@aevum.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Nick Wellnhofer.
+This software is copyright (c) 2016 by Nick Wellnhofer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
